#############
pyramid_royal
#############

.. image:: https://travis-ci.org/hadrien/pyramid_royal.png?branch=master
   :target: https://travis-ci.org/hadrien/pyramid_royal

.. image:: https://coveralls.io/repos/hadrien/pyramid_royal/badge.png
   :target: https://coveralls.io/r/hadrien/pyramid_royal

.. image:: https://pypip.in/d/pyramid_royal/badge.png
   :target: https://crate.io/packages/pyramid_royal/


Royal is a pyramid extension which eases writing RESTful web applications.

For more information on traversal algorithm, refer to `Pyramid documentation
<http://docs.pylonsproject.org/projects/pyramid/en/latest/narr/traversal.html>`_
